@@ -35,6 +35,7 @@ class AEMvAFVPDevice(FVPDevice):
     def validate(
         self,
         bl1,
+        boot_args,
         command,
         dtb,
         fip,
@@ -42,6 +43,7 @@ class AEMvAFVPDevice(FVPDevice):
         rootfs,
         uefi,
         parameters,
+        prompt,
         modules,
         tests,
         **kwargs,
@@ -52,6 +54,10 @@ class AEMvAFVPDevice(FVPDevice):
                 f"Invalid option(s) for fvp devices: {', '.join(sorted(invalid_args))}"
             )
 
+        if boot_args and '"' in boot_args:
+            raise InvalidArgument('argument --boot-args should not contains "')
+        if prompt and '"' in prompt:
+            raise InvalidArgument('argument --prompt should not contains "')
         if modules and compression(modules) not in [("tar", "gz"), ("tar", "xz")]:
             raise InvalidArgument(
                 "argument --modules should be a .tar.gz, tar.xz or .tgz"
@@ -71,6 +77,11 @@ class AEMvAFVPDevice(FVPDevice):
         kwargs["rootfs"] = notnone(kwargs.get("rootfs"), self.rootfs)
         kwargs["uefi"] = notnone(kwargs.get("uefi"), self.uefi)
 
+        if kwargs["tux_prompt"]:
+            kwargs["tux_prompt"] = [kwargs["tux_prompt"]]
+        else:
+            kwargs["tux_prompt"] = []
+
         # render the template
         tests = [
             t.render(
@@ -83,20 +94,18 @@ class AEMvAFVPDevice(FVPDevice):
             )
             for t in kwargs["tests"]
         ]
-        return (
-            templates.jobs().get_template("fvp-aemva.yaml.jinja2").render(**kwargs)
-            + "\n"
-            + "".join(tests)
-        )
+        return templates.jobs().get_template("fvp-aemva.yaml.jinja2").render(
+            **kwargs
+        ) + "".join(tests)
 
-    def extra_assets(self, tmpdir, dtb, kernel, **kwargs):
+    def extra_assets(self, tmpdir, dtb, kernel, tux_boot_args, **kwargs):
         dtb = notnone(dtb, self.dtb).split("/")[-1]
         kernel = notnone(kernel, self.kernel).split("/")[-1]
         # Drop the extension if the kernel is compressed. LAVA will decompress it for us.
         if compression(kernel)[1]:
             kernel = kernel[: -1 - len(compression(kernel)[1])]
         (tmpdir / "startup.nsh").write_text(
-            f"{kernel} dtb={dtb} console=ttyAMA0 earlycon=pl011,0x1c090000 root=/dev/vda ip=dhcp",
+            f"{kernel} dtb={dtb} {tux_boot_args + ' ' if tux_boot_args else ''}console=ttyAMA0 earlycon=pl011,0x1c090000 root=/dev/vda ip=dhcp",
             encoding="utf-8",
         )
         return [f"file://{tmpdir / 'startup.nsh'}"]
@@ -200,6 +209,19 @@ class FVPMorelloBusybox(MorelloFVPDevice):
     virtiop9_path = "/etc"
 
 
+class FVPMorelloDebian(MorelloFVPDevice):
+    name = "fvp-morello-debian"
+
+    prompts = ["morello-deb:~#"]
+    support_tests = True
+    auto_login = {
+        "login_prompt": "login:",
+        "username": "root",
+        "password_prompt": "Password:",
+        "password": "morello",
+    }
+
+
 class FVPMorelloBaremetal(MorelloFVPDevice):
     name = "fvp-morello-baremetal"
 
